@@ -18,11 +18,10 @@ datasets::mtcars %.>%
 
 ## ----rename3-------------------------------------------------------------
 datasets::mtcars %>%
-  rename_at(names(mp), function(si) { mp[si] }) %>%
+  rename_at(names(mp), funs(function(si) { mp[si] })) %>%
   head()
 
-## ----rename4-------------------------------------------------------------
-datasets::mtcars %.>%
-  rename_mp(., mp) %.>%
-  head(.)
+## ----swap----------------------------------------------------------------
+data.frame(a = 1, b = 2) %.>%
+  rename_se(., c('a', 'b') := c('b', 'a'))
 
